# CPDAG Estimation using PC-Algorithm

## Overview

This package provides functions to estimate a skeleton graph and a
completed partially acyclic graph (CPDAG) from a data matrix that
describes the appearance patterns of the graph nodes.  The detailed
algorithm is written in [Kalisch2007].

## Code

The source code is available at https://github.com/keiichishima/pcalg

## Bug Reports

Please submit bug reports or patches through the GitHub interface.

## Contributors

- Satoru Kobayashi, https://github.com/cpflat
- basilnsaeed, https://github.com/basilnsaeed
- Dr. Georg M. Goerg
- limjcst, https://github.com/limjcst
- ElementAI, https://github.com/ElementAI

## References

[Kalisch2007] Markus Kalisch and Peter Bhlmann. Estimating
high-dimensional directed acyclic graphs with the pc-algorithm. In The
Journal of Machine Learning Research, Vol. 8, pp. 613-636, 2007.

## Author

Keiichi SHIMA
/ Internet Initiative Japan Inc.
/ WIDE project
